==> haskell-half-0.3.3-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-half.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 half
version:              0.3.3
visibility:           public
id:                   half-0.3.3-3CA28O0gQhxBFDzBPTgQ4d
key:                  half-0.3.3-3CA28O0gQhxBFDzBPTgQ4d
license:              BSD-3-Clause
copyright:            Copyright (C) 2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/half
synopsis:             Half-precision floating-point
description:          Half-precision floating-point.
category:             Numeric
abi:                  43c79f1926bbd65d55abd3a7d066d3bc
exposed:              True
exposed-modules:      Numeric.Half Numeric.Half.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/half-0.3.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/half-0.3.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/half-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-half
hs-libraries:         HShalf-0.3.3-3CA28O0gQhxBFDzBPTgQ4d
depends:
    base-4.17.2.1 binary-0.8.9.1 deepseq-1.4.8.0
    template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-half/html/half.haddock
haddock-html:         /usr/share/doc/haskell-half/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-half-0.3.3-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-half.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 half
version:              0.3.3
visibility:           public
id:                   half-0.3.3-CgqOR7kbim92dxQOVetCLW
key:                  half-0.3.3-CgqOR7kbim92dxQOVetCLW
license:              BSD-3-Clause
copyright:            Copyright (C) 2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/half
synopsis:             Half-precision floating-point
description:          Half-precision floating-point.
category:             Numeric
abi:                  98cb09353044070c92ee706882bad084
exposed:              True
exposed-modules:      Numeric.Half Numeric.Half.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/half-0.3.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/half-0.3.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/half-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-half
hs-libraries:         HShalf-0.3.3-CgqOR7kbim92dxQOVetCLW
depends:
    base-4.17.2.1 binary-0.8.9.1 deepseq-1.4.8.0
    template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-half/html/half.haddock
haddock-html:         /usr/share/doc/haskell-half/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
